While GEOWATCH is designed and intended to be a fully open source system, some
aspects of the GEOWATCH module are developed in private. Additionally, there are
some data sources which will not be made public.

This page is meant to provide references to these resources that require
authentication to our internal collaberators. If you do not have credentials
you will not be able to access these resources.

+----------------------------------------------------------+----------------------------------------------------------------+
| The Internal SMART GEOWATCH Python Module                | https://gitlab.kitware.com/smart/watch/                        |
+----------------------------------------------------------+----------------------------------------------------------------+
| The Phase 1 Internal SMART GEOWATCH DVC Repo             | https://gitlab.kitware.com/smart/smart_watch_dvc/              |
+----------------------------------------------------------+----------------------------------------------------------------+
| The Phase 2 Internal SMART GEOWATCH DVC Data Repo        | https://gitlab.kitware.com/smart/smart_data_dvc/               |
+----------------------------------------------------------+----------------------------------------------------------------+
| The Phase 2 Internal SMART GEOWATCH DVC Experiment Repo  | https://gitlab.kitware.com/smart/smart_expt_dvc/               |
+----------------------------------------------------------+----------------------------------------------------------------+


Also see: https://gitlab.kitware.com/smart/watch/-/wikis/Resource-Clearinghouse
